@@ -168,7 +168,7 @@ terminal_preferences_dialog_init (TerminalPreferencesDialog *dialog)
   const gchar      *props_active[] = { "title-mode", "command-login-shell",
                                        "command-update-records", "run-custom-command",
                                        "use-default-working-dir", "scrolling-on-output",
-                                       "scrolling-on-keystroke", "scrolling-bar",
+                                       "scrolling-on-keystroke", "scrolling-bar", "overlay-scrolling",
                                        "scrolling-unlimited", "misc-cursor-shape",
                                        "misc-cursor-blinks", "font-allow-bold",
                                        "font-use-system", "text-blink-mode",
@@ -187,7 +187,7 @@ terminal_preferences_dialog_init (TerminalPreferencesDialog *dialog)
                                        "dropdown-keep-open-default", "dropdown-keep-above",
                                        "dropdown-toggle-focus", "dropdown-status-icon",
                                        "dropdown-move-to-active", "dropdown-always-show-tabs",
-                                       "dropdown-show-borders"
+                                       "dropdown-show-borders", "misc-right-click-action"
                                      };
   const gchar      *props_color[] =  { "color-foreground", "color-background",
                                        "tab-activity-color", "color-cursor-foreground",
