@@ -56,6 +56,7 @@ terminal_util_show_about_dialog (GtkWindow *parent)
     "Benedikt Meurer <benny@xfce.org>",
     "Nick Schermer <nick@xfce.org>",
     "Igor Zakharov <f2404@yandex.ru>",
+    "Sergios - Anestis Kefalidis <sergioskefalidis@gmail.com>",
     NULL,
   };
 
@@ -81,9 +82,10 @@ terminal_util_show_about_dialog (GtkWindow *parent)
                          "documenters", documenters,
                          "copyright", "Copyright \302\251 2003-2008 Benedikt Meurer\n"
                                       "Copyright \302\251 2007-2012 Nick Schermer\n"
-                                      "Copyright \302\251 2016-2020 Igor Zakharov",
+                                      "Copyright \302\251 2016-2020 Igor Zakharov\n"
+                                      "Copyright \302\251 2021 Sergios - Anestis Kefalidis",
                          "license", XFCE_LICENSE_GPL,
-                         "logo-icon-name", "utilities-terminal",
+                         "logo-icon-name", "org.xfce.terminal",
                          "program-name", PACKAGE_NAME,
                          "translator-credits", _("translator-credits"),
                          "version", PACKAGE_VERSION,
@@ -143,3 +145,12 @@ terminal_util_activate_window (GtkWindow *window)
   gtk_window_present (window);
 #endif
 }
+
+
+
+void
+terminal_util_free_data (gpointer  data,
+                         GClosure *closure)
+{
+  g_free (data);
+}
